@@ -1,8 +1,5 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2021-08-06'; # DATE
-our $VERSION = '1.816'; # VERSION
-
 use 5.010001;
 #use strict; # enabled by Moo
 #use warnings; # enabled by Moo
@@ -14,6 +11,11 @@ use Locale::TextDomain::UTF8 'Perinci-CmdLine-Classic';
 use Perinci::Object;
 use Scalar::Util qw(blessed);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-10-19'; # DATE
+our $DIST = 'Perinci-CmdLine-Classic'; # DIST
+our $VERSION = '1.817'; # VERSION
+
 our $REQ_VERSION = 0; # version requested by user
 
 extends 'Perinci::CmdLine::Base';
@@ -116,6 +118,7 @@ has default_prompt_template => (is=>'rw');
 sub VERSION {
     my ($pkg, $req) = @_;
     $REQ_VERSION = $req;
+    $pkg->SUPER::VERSION(@_);
 }
 
 sub BUILD {
@@ -385,7 +388,7 @@ my $setup_progress;
 sub _setup_progress_output {
     my $self = shift;
 
-    if ($ENV{PROGRESS} // (-t STDOUT)) {
+    if ($ENV{PROGRESS} // (-t STDOUT)) { ## no critic: InputOutput::ProhibitInteractiveTest
         require Progress::Any::Output;
         my $out = Progress::Any::Output->set("TermProgressBarColor");
         $setup_progress = 1;
@@ -500,7 +503,7 @@ sub hook_format_result {
     my $fres;
     if ($res->[3]{is_stream}) {
         log_trace("Result is a stream");
-        return undef;
+        return;
     } elsif ($res->[3]{'x.hint.result_binary'} && $format =~ /text/) {
         $fres = $res->[2];
     } else {
@@ -612,7 +615,7 @@ sub action_subcommands {
 }
 
 sub action_version {
-    no strict 'refs';
+    no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
 
     my ($self, $r) = @_;
 
@@ -778,7 +781,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.816 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2021-08-06.
+This document describes version 1.817 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2022-10-19.
 
 =head1 SYNOPSIS
 
@@ -945,12 +948,6 @@ All those supported by L<Perinci::CmdLine::Base>, plus:
 If set to true, then when formatting to C<text> formats, this class won't print
 any newline to keep the data being printed unmodified.
 
-=head1 CONTRIBUTOR
-
-=for stopwords Steven Haryanto
-
-Steven Haryanto <sharyanto@cpan.org>
-
 =head1 ATTRIBUTES
 
 All the attributes of L<Perinci::CmdLine::Base>, plus:
@@ -1027,14 +1024,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Classic>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine-Classic>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Perinci::CmdLine::Any>, L<Perinci::CmdLine::Lite>.
@@ -1043,11 +1032,43 @@ L<Perinci::CmdLine::Any>, L<Perinci::CmdLine::Lite>.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine-Classic>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
